from pages.admin.page import PageAdmin
from pages.admin.pagecontent import PageContentAdmin
from pages.admin.pagecontenttype import PageContentTypeAdmin
from pages.admin.pagecontenttypes import PageSlugContentAdmin
from pages.admin.pagecontenttypes import PageRedirectContentAdmin
from pages.admin.pagecontenttypes import PageMetaContentAdmin
from pages.admin.pagecontenttypes import PageTextContentAdmin
from pages.admin.pagecontenttypes import PageImageContentAdmin
